import i18n from 'i18next'
import { initReactI18next } from 'react-i18next'

export const getInitialLanguageCode = () => {
  const savedLanguage = localStorage.getItem('language')
  return savedLanguage || 'es'
}

i18n.use(initReactI18next).init({
  fallbackLng: 'es',
  lng: getInitialLanguageCode(),
  interpolation: {
    escapeValue: false,
  },
  resources: {
    en: {
      translation: {
        // home
        home_description:
          'Here we will describe the application, the objective of the project, and so on. Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat.',
        home_title: 'microservices testing',
        // patterns
        patterns_available_pattarns: 'available patterns',
        patterns_create_pattern: 'create pattern',
        patterns_delete_pattern_confirmation_modal_body:
          'if you delete the pattern, all its associated data will be removed and cannot be restored',
        patterns_delete_pattern_confirmation_modal_header: 'delete pattern',
        patterns_delete_pattern_error:
          'we are having some issues deleting the pattern',
        patterns_delete_pattern_success:
          'the pattern has been deleted successfully',
        patterns_edit: 'edit pattern',
        patterns_not_found: 'no patterns found',
        patterns_pattern: 'pattern',
        patterns_patterns: 'patterns',
        // implementations
        implementations_add_implementation: 'add implementation',
        implementations_add_implementation_for_pattern:
          'create new implementation for',
        implementations_available_implementations: 'available implementations',
        implementations_dockerhub_image_name: 'dockerhub image name',
        implementations_dockerhub_image_name_tooltip:
          'name of the Dockerhub image with the implementation',
        implementations_edit_implementation: 'edit implementation',
        implementations_implementations: 'implementations',
        implementations_not_found: 'no implementations available',
        // formalizations
        formalizations_add_formalization: 'add formalization',
        formalizations_create_formalization: 'create formalization',
        formalizations_formalizations: 'formalizations',
        formalizations_formalization: 'formalization',
        // animations
        animations_add_animation_file: 'add animation file',
        animations_add_animation_modal_header: 'create animation of pattern',
        animations_animations: 'animations',
        animations_create_animation: 'create animation',
        animations_delete: 'delete animation',
        animations_delete_animation_confirmation_modal_body:
          'if you delete the animation, all its associated data will be removed and cannot be restored',
        adnimations_delete_success: 'animation deleted succesfully',
        animations_not_found: 'no animations available',
        animations_available: 'available animations',
        // reports
        reports_available_reports: 'available reports',
        reports_view_reports: 'view reports',
        reports_table_title: 'reports of implementation',
        reports_delete_success: 'report deleted succesfully',
        reports_delete: 'delete report',
        reports_delete_report_confirmation_modal_body:
          'are you sure you want to delete this report? it cannot be recovered',
        reports_tests_running_alert:
          'Tests are running. You will be notified when the report is ready.',
        //generic
        add: 'add',
        cancel: 'cancel',
        create: 'create',
        created_date: 'created date',
        date: 'date',
        delete: 'delete',
        description: 'description',
        download: 'download',
        edit: 'edit',
        image: 'image',
        name: 'name',
        report: 'report',
        run: 'run',
        run_tests: 'run tests',
        run_tests_modal_header_step_1_part_1:
          'run tests for the implementation',
        run_tests_modal_header_step_1_part_2: 'of the pattern',
        run_tests_modal_header_step_2_part_1:
          'download the file, complete it and upload it',
        save: 'save',
        strategy: 'strategy',
        test: 'test',
        test_cases_instantiation: 'test cases instantiation',
        view: 'view',
        wrapper: 'wrapper',
        completed_wrapper: 'completed wrapper',
        new_report_available: 'a new report is available!',
        new_report_error: 'an error has occur while generating the report',
      },
    },
    es: {
      translation: {
        // home
        home_description:
          'En este lugar se describe lo que hace la aplicación, el objetivo del proyect, etc... Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat.',
        home_title: 'testing de microservicios',
        // patterns
        patterns_available_pattarns: 'patrones disponibles',
        patterns_create_pattern: 'crear patrón',
        patterns_delete_pattern_confirmation_modal_body:
          'al eliminar el patrón, todos sus datos relacionados serán eliminados',
        patterns_delete_pattern_confirmation_modal_header: 'eliminar patron',
        patterns_delete_pattern_error:
          'ha ocurrido un problema al eliminar el patrón',
        patterns_delete_pattern_success: 'se ha eliminado el patrón con éxito',
        patterns_edit: 'editar patrón',
        patterns_not_found: 'no se encontraron patrones',
        patterns_pattern: 'patrón',
        patterns_patterns: 'patrones',
        // implementations
        implementations_add_implementation: 'agregar implementación',
        implementations_add_implementation_for_pattern:
          'crear nueva implementación para',
        implementations_available_implementations:
          'implementaciones disponibles',
        implementations_dockerhub_image_name:
          'nombre de la imagen en Dockerhub',
        implementations_dockerhub_image_name_tooltip:
          'nombre de la imagen en Dockerhub con la implementación',
        implementations_edit_implementation: 'editar implementación',
        implementations_implementations: 'implementaciones',
        implementations_not_found: 'no hay implementaciones disponibles',
        // formalizations
        formalizations_add_formalization: 'agregar formalización',
        formalizations_create_formalization: 'crear formalización',
        formalizations_formalizations: 'formalizaciones',
        formalizations_formalization: 'formalización',
        // animations
        animations_add_animation_file: 'agregar archivo de animación',
        animations_add_animation_modal_header: 'crear animación del patrón',
        animations_animations: 'animaciones',
        animations_create_animation: 'crear animación',
        animations_delete: 'eliminar animación',
        animations_delete_animation_confirmation_modal_body:
          'al eliminar la animación, todos sus datos relacionados serán eliminados',
        animations_delete_success: 'se ha eliminado la animación con éxito',
        animations_not_found: 'no hay animaciones disponibles',
        animations_available: 'animaciones disponibles',
        // reports
        reports_available_reports: 'reportes disponibles',
        reports_view_reports: 'ver reportes',
        reports_table_title: 'reportes de implementación',
        reports_delete_success: 'reporte eliminado satisfactoriamente',
        reports_delete: 'eliminar reporte',
        reports_delete_report_confirmation_modal_body:
          'está seguro que desea continuar? el reporte no podrá ser recuperado',
        reports_tests_running_alert:
          'Se están corriendo los tests. Le notificaremos al finalizar.',
        // generic
        add: 'agregar',
        cancel: 'cancelar',
        create: 'crear',
        created_date: 'fecha de creación',
        date: 'fecha',
        delete: 'eliminar',
        description: 'descripción',
        download: 'descargar',
        edit: 'editar',
        image: 'imágen',
        name: 'nombre',
        report: 'reporte',
        run: 'correr',
        run_tests: 'correr tests',
        run_tests_modal_header_step_1_part_1:
          'correr tests de la implementación',
        run_tests_modal_header_step_1_part_2: 'del patrón',
        run_tests_modal_header_step_2_part_1:
          'descargue el archivo, complételo, y súbalo denuevo',
        save: 'guardar',
        strategy: 'estrategia',
        test: 'prueba',
        test_cases_instantiation: 'instanciación de casos de pruebas',
        view: 'ver',
        wrapper: 'wrapper',
        completed_wrapper: 'wrapper completo',
        new_report_available: 'nuevo reporte disponible!',
        new_report_error: 'ha ocurrido un error al generar el reporte',
      },
    },
  },
})

export default i18n
