import { ButtonProps, Tooltip, useDisclosure, Text } from '@chakra-ui/react'
import React from 'react'
import { Implementation, Pattern } from 'src/models'
import { RunTestsButtonModal } from './run-tests-button-modal'
import { useTranslation } from 'react-i18next'
import { capitalize } from 'lodash'
import { useTestsRunningStore } from './tests-running-store'

export type RunTestsButtonProps = {
  implementation: Implementation
  pattern: Pattern
  hasTooltip?: boolean
  children: React.ReactElement<ButtonProps>
}

export const RunTestsButton: React.FC<RunTestsButtonProps> = ({
  implementation,
  pattern,
  hasTooltip = false,
  children,
}) => {
  const { t } = useTranslation()
  const disclosure = useDisclosure()
  const store = useTestsRunningStore()
  const btn = React.cloneElement(children, {
    isDisabled: store.isRunning,
    onClick: disclosure.onOpen,
  })

  return (
    <>
      <Tooltip isDisabled={!hasTooltip} label={capitalize(t('run_tests'))}>
        {btn}
      </Tooltip>

      {disclosure.isOpen && (
        <RunTestsButtonModal
          implementation={implementation}
          pattern={pattern}
          disclosure={disclosure}
        />
      )}
    </>
  )
}
