import { AxiosError } from 'axios'
import { useMutation as useRQMutation, UseMutationOptions } from 'react-query'

import { Pattern, UpdatePatternRequest } from 'src/models'
import axiosService from 'src/services/axios-service'

export namespace UpdatePatternMutation {
  export type Params = UpdatePatternRequest
  export type Response = Pattern

  export const key = ['update', 'pattern']

  export const mutationFn = (params: Params) =>
    axiosService
      .put<Response>(`/patterns/${params.id}`, params)
      .then((res) => res.data)

  export const useMutation = (
    options: UseMutationOptions<Response, AxiosError, UpdatePatternRequest> = {}
  ) => {
    return useRQMutation(mutationFn, { ...options, mutationKey: key })
  }
}
